[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,212 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/devices>
#include <cuda/hierarchy>
#include <cuda/launch>
#include <cuda/std/cstddef>
#include <cuda/std/numeric>
#include <cuda/std/type_traits>
#include <cuda/std/utility>
#include <cuda/stream>
#include <cuda/warp>
#include <cuda/experimental/group.cuh>
#include "group_testing.cuh"
namespace
{
template <cuda::std::size_t N, class Config>
__device__ void test_take(Config config)
{
constexpr auto n = static_cast<unsigned>(N);
// Test static N.
{
using Mapping = cudax::take<N>;
// Test default constructor.
{
static_assert(cuda::std::is_trivially_default_constructible_v<Mapping>);
static_assert(cuda::std::is_empty_v<Mapping>);
Mapping mapping;
CHECK(mapping.unit_count() == n);
}
// Test static_unit_count().
{
static_assert(cuda::std::is_same_v<cuda::std::size_t, decltype(Mapping::static_unit_count())>);
static_assert(noexcept(Mapping::static_unit_count()));
static_assert(Mapping::static_unit_count() == N);
}
// Test unit_count().
{
static_assert(cuda::std::is_same_v<unsigned, decltype(cuda::std::declval<const Mapping>().unit_count())>);
static_assert(noexcept(cuda::std::declval<const Mapping>().unit_count()));
const Mapping mapping;
CHECK(mapping.unit_count() == n);
}
// Test map(...).
{
const cudax::this_warp parent_group{config};
const ThreadsInWarpMappingResult prev_mapping_result;
static_assert(cudax::__group_mapping_result<decltype(cuda::std::declval<const Mapping>().map(
cuda::gpu_thread, parent_group, prev_mapping_result))>);
static_assert(
noexcept(cuda::std::declval<const Mapping>().map(cuda::gpu_thread, parent_group, prev_mapping_result)));
const Mapping mapping;
auto result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
using Result = decltype(result);
static_assert(Result::static_group_count() == ThreadsInWarpMappingResult::static_group_count());
static_assert(Result::static_unit_count() == N);
static_assert(Result::is_always_exhaustive()
== (Result::static_unit_count() == ThreadsInWarpMappingResult::static_unit_count()));
static_assert(Result::is_always_contiguous());
const auto is_valid_ref = cuda::std::cmp_less(cuda::gpu_thread.rank(cuda::warp), n);
CHECK(result.is_valid() == is_valid_ref);
if (is_valid_ref)
{
CHECK(result.group_count() == prev_mapping_result.group_count());
CHECK(result.group_rank() == prev_mapping_result.group_rank());
CHECK(result.unit_count() == n);
CHECK(result.unit_rank() == cuda::gpu_thread.rank(cuda::warp));
const auto lane_mask_ref = ((N < 32) ? ((1u << N) - 1) : ~0u);
CHECK(result.lane_mask() == cuda::device::lane_mask{lane_mask_ref});
CHECK(result.is_valid());
}
}
}
// Test dynamic Ns.
{
using Mapping = cudax::take<cuda::std::dynamic_extent>;
// Test default constructor.
{
static_assert(cuda::std::is_nothrow_default_constructible_v<Mapping>);
Mapping mapping;
CHECK(mapping.unit_count() == 0);
}
// Test the mapping is constructible from n.
{
static_assert(cuda::std::is_nothrow_constructible_v<Mapping, unsigned>);
cudax::take mapping{n};
static_assert(cuda::std::is_same_v<decltype(mapping), Mapping>);
CHECK(mapping.unit_count() == n);
}
// Test static_unit_count().
{
static_assert(cuda::std::is_same_v<cuda::std::size_t, decltype(Mapping::static_unit_count())>);
static_assert(noexcept(Mapping::static_unit_count()));
static_assert(Mapping::static_unit_count() == cuda::std::dynamic_extent);
}
// Test unit_count().
{
static_assert(cuda::std::is_same_v<unsigned, decltype(cuda::std::declval<const Mapping>().unit_count())>);
static_assert(noexcept(cuda::std::declval<const Mapping>().unit_count()));
const Mapping mapping{n};
CHECK(mapping.unit_count() == n);
}
// Test map(...).
{
const cudax::this_warp parent_group{config};
const ThreadsInWarpMappingResult prev_mapping_result;
static_assert(cudax::__group_mapping_result<decltype(cuda::std::declval<const Mapping>().map(
cuda::gpu_thread, parent_group, prev_mapping_result))>);
static_assert(
noexcept(cuda::std::declval<const Mapping>().map(cuda::gpu_thread, parent_group, prev_mapping_result)));
const Mapping mapping{n};
auto result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
using Result = decltype(result);
static_assert(Result::static_group_count() == ThreadsInWarpMappingResult::static_group_count());
static_assert(Result::static_unit_count() == cuda::std::dynamic_extent);
static_assert(!Result::is_always_exhaustive());
static_assert(Result::is_always_contiguous());
const auto is_valid_ref = cuda::std::cmp_less(cuda::gpu_thread.rank(cuda::warp), n);
CHECK(result.is_valid() == is_valid_ref);
if (is_valid_ref)
{
CHECK(result.group_count() == prev_mapping_result.group_count());
CHECK(result.group_rank() == prev_mapping_result.group_rank());
CHECK(result.unit_count() == n);
CHECK(result.unit_rank() == cuda::gpu_thread.rank(cuda::warp));
const auto lane_mask_ref = ((N < 32) ? ((1u << N) - 1) : ~0u);
CHECK(result.lane_mask() == cuda::device::lane_mask{lane_mask_ref});
CHECK(result.is_valid());
}
}
}
}
struct TestKernel
{
template <class Config>
__device__ void operator()(const Config& config)
{
test_take<0>(config);
test_take<1>(config);
test_take<2>(config);
test_take<3>(config);
test_take<4>(config);
test_take<14>(config);
test_take<16>(config);
test_take<30>(config);
test_take<32>(config);
}
};
} // namespace
C2H_TEST("Take mapping", "[group]")
{
const auto device = cuda::devices[0];
const cuda::stream stream{device};
{
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<8, 4>());
cuda::launch(stream, config, TestKernel{});
}
{
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims(dim3{8, 4}));
cuda::launch(stream, config, TestKernel{});
}
stream.sync();
}